<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// D
	'dump_description' => 'Sicherung und Wiederherstellung der Datenbank im SQLite-Format',
	'dump_slogan' => 'Sicherung und Wiederherstellung der  SPIP-Datenbank',
];
